### Community Contributed Configuration Resources

This directory is meant to store new configuration _Resource_ defintions.  

At this point in the development of _Junos EZ_, the practice of creating new _Resource_ definitions requires a number of skill-sets that trend into being a "Software Programmer".  As _Junos EZ_ development progresses, I hope to make the process of definiting new _Resource_ as easy as new Operational Tables and Views.

If you are interested in learning how to create your own _Resource_ definitions, please contact the maintainers of _Junos EZ_ for guidance.

Thank you for your contributions!
